# Satastro - Astronomy for and with satellites

[![PyPI - Version](https://img.shields.io/pypi/v/satastro)](https://pypi.org/project/satastro/)

## Description

Satastro is a Python package to combine astronomy and satellites. It enables to calculate the RA-Dec position of a satellite or asteroid in the sky when viewed from Earth. It also enables to calculate these astronomical positions when the observer is a satellite orbiting the Earth.

Satastro also provides a simple to use interface with [NASA JPL Horizons](https://ssd.jpl.nasa.gov/horizons/) to retrieve ephemerides of Small Solar System Bodies.

With Satastro, one can easily plot visibility maps for asteroids or satellites, along with night times. It is also offers the possibility to plot star field with the UCAC4 or GaiaDR3 catalogs to find the target in the sky.

## Installation

This package can be very easily installed using pip :

 ```pip install satastro```

## Contributing

Contributions are welcome! Please open an issue or submit a pull request on GitHub.

## License

This project is licensed under the GNU General Public License v3 (GPLv3). See the LICENSE file for details.